![ATAK Screenshot with PyTAK Logo.](media/atak_screenshot_with_pytak_logo-x25.jpg)

# Python Team Awareness Kit

PyTAK is a Python Module for creating [TAK](https://tak.gov) clients, servers & gateways.

PyTAK includes:

- TAK Protocol support for interconnecting with ATAK, WinTAK, iTAK & TAK Server.
- Classes for handling TAK, Cursor on Target (CoT) & non-CoT data.
- Functions for parsing and serializing TAK & CoT data.
- Functions for sending and receiving TAK & CoT data over a network.

## Documentation

See [PyTAK documentation](https://pytak.rtfd.io/) for instructions on getting 
started with PyTAK, examples, configuration & troubleshooting options.

## License & Copyright

Copyright Sensors & Signals LLC https://www.snstac.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

asyncio_dgram is Copyright (c) 2019 Justin Bronder and is licensed under the MIT 
License, see pytak/asyncio_dgram/LICENSE for details.

